@@ -6,10 +6,12 @@
 ( cd usr/lib/pkgconfig ; ln -sf libpng12.pc libpng.pc )
 ( cd usr/lib ; rm -rf libpng12.so )
 ( cd usr/lib ; ln -sf libpng12.so.0 libpng12.so )
+( cd usr/lib ; rm -rf libpng.so.0 )
+( cd usr/lib ; ln -sf libpng.so.3 libpng.so.0 )
 ( cd usr/lib ; rm -rf libpng.so.3 )
-( cd usr/lib ; ln -sf libpng.so.3.1.2.5 libpng.so.3 )
+( cd usr/lib ; ln -sf libpng.so.3.1.2.12 libpng.so.3 )
 ( cd usr/lib ; rm -rf libpng12.so.0 )
-( cd usr/lib ; ln -sf libpng12.so.0.1.2.5 libpng12.so.0 )
+( cd usr/lib ; ln -sf libpng12.so.0.1.2.12 libpng12.so.0 )
 ( cd usr/lib ; rm -rf libpng.a )
 ( cd usr/lib ; ln -sf libpng12.a libpng.a )
 ( cd usr/include ; rm -rf pngconf.h )
